==> ksmoothdock-3.6.1.tar.gz: ksmoothdock/src/welcomedialog.h <==
/***************************************************************************
                          welcomedialog.h  -  description
                             -------------------
    begin                : Tue Jun 10 22:18:34 BST 2003
    copyright            : (C) 2003-2005 by KSmoothDock team
    email                : dangvd@yahoo.com
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/
 
#ifndef WELCOMEDIALOG_H
#define WELCOMEDIALOG_H

#include <qdialog.h>

class QVBoxLayout;
class QHBoxLayout;
class QGridLayout;
class QLabel;
class QButtonGroup;
class QRadioButton;
class QCheckBox;
class QPushButton;
class QGroupBox;
class QComboBox;

#include "constants.h"

class WelcomeDialog : public QDialog
{
    Q_OBJECT

public:
    WelcomeDialog( QWidget* parent = 0, const char* name = 0, bool modal = FALSE, WFlags fl = 0 );
    ~WelcomeDialog();

    QLabel* textLabel2;
    QGroupBox* groupBox1;
    QButtonGroup* buttonGroup2;
    QRadioButton* rbNormalZoom;
    QLabel* textLabel3;
    QLabel* textLabel4;
    QRadioButton* rbParabolicZoom;
    QGroupBox* groupBox2;
    QCheckBox* cbClock;
    QCheckBox* cbPager;
    QLabel* textLabel6;
    QCheckBox* cbQuickLaunch;
    QLabel* textLabel7;
    QLabel* textLabel2_3;
    QCheckBox* cbShowWinAllDesks;
    QLabel* textLabel1_3;
    QLabel* textLabel9;
    QCheckBox* cbTaskbar;
    QPushButton* pushButton3;
    QGroupBox* groupBox22;
    QLabel* textLabel5_3;
    QCheckBox* cbAutohide;
    QLabel* textLabel1;

public:
  int getZoomMode();
  int getShowPager();
  int getShowTaskbar();
  int getShowClock();
	int getShowWinAllDesks();
  PanelPosition getPosition();
  int getAutohide();

public slots:
    virtual void pushButton3_clicked();
    virtual void cbTaskbar_stateChanged( int );

protected:

protected slots:
    virtual void languageChange();

};

#endif // WELCOMEDIALOG_H

==> ksmoothdock-4.0.1.tar.gz: ksmoothdock/src/welcomedialog.h <==
/***************************************************************************
                          welcomedialog.h  -  description
                             -------------------
    begin                : Tue Jun 10 22:18:34 BST 2003
    copyright            : (C) 2003-2005 by KSmoothDock team
    email                : dangvd@yahoo.com
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/
 
#ifndef WELCOMEDIALOG_H
#define WELCOMEDIALOG_H

#include <qdialog.h>

class QVBoxLayout;
class QHBoxLayout;
class QGridLayout;
class QLabel;
class QButtonGroup;
class QRadioButton;
class QCheckBox;
class QPushButton;
class QGroupBox;
class QComboBox;

#include "constants.h"

class WelcomeDialog : public QDialog
{
    Q_OBJECT

public:
    WelcomeDialog( QWidget* parent = 0, const char* name = 0, bool modal = FALSE, WFlags fl = 0 );
    ~WelcomeDialog();

    ZoomMode getZoomMode();
    int isShowingPager();
    int isShowingTaskbar();
    int isShowingClock();
    int isShowingWindowsAllDesktops();
    //PanelPosition getPosition();

public slots:
    virtual void pushButton3_clicked();
    virtual void cbTaskbar_stateChanged( int );

protected slots:
    virtual void languageChange();

private:
    QLabel* textLabel2;
    QGroupBox* groupBox1;
    QButtonGroup* buttonGroup2;
    QRadioButton* rbNormalZoom;
    QLabel* textLabel3;
    QLabel* textLabel4;
    QRadioButton* rbParabolicZoom;
    QGroupBox* groupBox2;
    QCheckBox* cbClock;
    QCheckBox* cbPager;
    QLabel* textLabel6;
    QCheckBox* cbQuickLaunch;
    QLabel* textLabel7;
    QLabel* textLabel2_3;
    QCheckBox* cbShowWinAllDesks;
    QLabel* textLabel1_3;
    QLabel* textLabel9;
    QCheckBox* cbTaskbar;
    QPushButton* pushButton3;
    QLabel* textLabel1;
};

#endif // WELCOMEDIALOG_H
